%% Pressure Data Analysis Script
% Input: Raw pressure data from chamber pressure.
% Output: Average pressure and statistical analysis of pressure data. 
% Note: Before running this script pressure data must be imported to the
%       MATLAB workspace with a TDMS reader that is complient with the current
%       LabVIEW program used for data aqusition.
%% 
% Structure input data and create a time vector equal to the # values
% pressure data
lenght=size(pressure,1);
time_vector=(1:lenght);
time_vector=time_vector(:);
%% 
% polyfit is used to find the coefficients A and B for the falling average
% of the raw pressure plot,Y=Ax+B
p = polyfit(time_vector,pressure,1);

% Exctract variable A and B from polyfit function: Y=Ax+B
A=p(1,1);
B=p(1,2);
%% 
% Offset each data value in pressure vector by A and B   
for f = 1 : lenght;
pressure_adjusted(f,1)=(pressure(f,1))+(-A*f)+(-B+0); %adjusts and and equals ut slope of pressure data
end
%% 
% Finding peak value and index
[pks,locs]= findpeaks(smooth(pressure_adjusted),'MinPeakHeight',25,'MinPeakProminence',2);
%% 
% Remove incomplete pressure curves
locs_to_remove = any(locs<5200, 2);
locs(locs_to_remove,:) = [];
pks(locs_to_remove,:) = [];
%% 
% For 700RPM each pressure series is clipped at 10400 data points
nRows_pks = size(pks, 1);
nRows_pa = size(pressure_adjusted, 1);
samples_from_peak = 5200 ; %found from visual inspection of pressure plot, ensures some overlap
sample_totsize = samples_from_peak*2;
%%
p_accumulated= zeros(sample_totsize,nRows_pks);
top  = zeros(nRows_pks,1);
low  = zeros(nRows_pks,1);
high = zeros(nRows_pks,1);
%%
for h= 1 : nRows_pks;
    top(h,1) = locs(h,1);
    low(h,1) = top(h,1) - samples_from_peak;
    high(h,1) = top(h,1) + samples_from_peak;
end

%%
% Remove last peak if vector is incomplete, incomplete vectors will lead to
% error in script 
nRows_mod = nRows_pks-1;

for z=1:nRows_mod;
    for u = 1 : 10400 ;
        start=low(z,1)+u-1;
        p_accumulated(u,z) = pressure_adjusted(start,1);
    end
end

%%
% Remove zero colums
p_accumulated(:,all(p_accumulated==0))=[];
% Create average pressure plot
%%
%%
% Offset each pressure plot from inlet valve closing = 1ATM
for a=1:260;
for b=1:nRows_mod;
p_accumulated_extracted_raw(a,b)=p_accumulated(2599+a,b);
end
end

%%
% Statistical analysis of pressure data
p_accumulated_offset_matrix=mean(p_accumulated_extracted_raw,1);%assigning ",1" takes mean of each row
p_correction_matrix=(p_accumulated_offset_matrix)-1;
p_correction_matrix_pos=(p_correction_matrix)*-1;
p_size=size(p_accumulated,1);

%% 
% Correction of pressure plot
for u=1:nRows_mod;
for s=1:p_size;
p_accumulated_mod(s,u) = (p_accumulated(s,u)) +(p_correction_matrix_pos(1,u));
end
end

%% 
% Average of corrected plot
p_avg = mean(p_accumulated_mod,2);
%%
% Plot
[pathstr,name,ext] = fileparts(fileName); %extract only filename
figure1 = figure;
% [pks_avg,locs_avg]= findpeaks(p_avg_mod,'MinPeakHeight',25,'MinPeakProminence',2);
% str = 'Peak pressure';
% annotation('textbox',dim,'String',str,'FitBoxToText','on');
axes1 = axes('Parent',figure1);
hold(axes1,'on');
plot(p_avg,'DisplayName','Average pressure','LineWidth',1);
xlabel('Sample number');
ylabel({'Pressure [bar]'});
title({name});
xlim(axes1,[0 10500]);
ylim(axes1,[-1 36]);
box(axes1,'on');
set(axes1,'FontSize',12,'XGrid','on','YGrid','on','YMinorGrid','on',...
    'YMinorTick','on');
legend1 = legend(axes1,'show');
set(legend1,...
    'Position',[0.669587071736655 0.825394039760783 0.130989583333333 0.0627962085308061],...
    'FontSize',12);
% %
% axXLim1 = get(axes1,'xlim');
% % Find the max
 ymax1 = max(p_avg);
% % Get coordinates for the max line
% maxValue1 = [ymax1 ymax1];
% % Plot the max
% statLine1 = plot(axXLim1,maxValue1,'DisplayName','   y max','Tag','max y',...
%     'Parent',axes1,...
%     'LineStyle','-.',...
%     'Color',[0 0 1]);
% %line(get(gca,'Xlim'), [max(p_avg) max(p_avg)],'color', 'red') 
%% 
% Save Pressure plot fig
print('-f1',name,'-dpng');

%% 

figure(2)
title('p_accumulated')
plot(p_accumulated)
%% 

figure(3)
title('Origial pressure data')
plot(pressure);
%% 

figure(4)
title('adjusted pressure data')
plot(pressure_adjusted)
%% 

% Statical analysis pressure data
standard_deviation = std(p_accumulated_mod,0,2);
variation = var(p_accumulated_mod,0,2);
%% 
% Save p_avg plot and standard deviation
save(name,'p_avg');
save(name,'standard_deviation','-append');


